@@ -1,9 +1,12 @@
 from typing import List, Literal, Optional
 
 from langchain_core.tools import BaseTool, BaseToolkit
-from pydantic import BaseModel, Field, create_model, SecretStr
+from pydantic import BaseModel, Field, create_model
 
 import requests
+
+from ....configurations.ado import AdoReposConfiguration
+from ....configurations.pgvector import PgVectorConfiguration
 from ...base.tool import BaseAction
 from .repos_wrapper import ReposApiWrapper
 from ...utils import clean_string, TOOLKIT_SPLITTER, get_max_toolkit_length, check_connection_response
@@ -14,20 +17,15 @@ name = "ado_repos"
 def _get_toolkit(tool) -> BaseToolkit:
     return AzureDevOpsReposToolkit().get_toolkit(
         selected_tools=tool['settings'].get('selected_tools', []),
-        organization_url=tool['settings'].get('organization_url', ""),
-        project=tool['settings'].get('project', ""),
-        token=tool['settings'].get('token', ""),
+        ado_repos_configuration=tool['settings']['ado_repos_configuration'],
         limit=tool['settings'].get('limit', 5),
-        repository_id=tool['settings'].get('repository_id', ""),
         base_branch=tool['settings'].get('base_branch', ""),
         active_branch=tool['settings'].get('active_branch', ""),
         toolkit_name=tool['settings'].get('toolkit_name', ""),
-        connection_string=tool['settings'].get('connection_string', None),
-        collection_name=str(tool['id']),
-        doctype='code',
-        embedding_model="HuggingFaceEmbeddings",
-        embedding_model_params={"model_name": "sentence-transformers/all-MiniLM-L6-v2"},
-        vectorstore_type="PGVector",
+        pgvector_configuration=tool['settings'].get('pgvector_configuration', {}),
+        embedding_model=tool['settings'].get('embedding_model'),
+        collection_name=tool['toolkit_name'],
+        alita=tool['settings'].get('alita', None),
     )
 
 def get_toolkit():
@@ -46,49 +44,23 @@ class AzureDevOpsReposToolkit(BaseToolkit):
         AzureDevOpsReposToolkit.toolkit_max_length = get_max_toolkit_length(selected_tools)
         m = create_model(
             name,
-            organization_url=(str, Field(title="Organization URL",
-                                                   description="ADO organization url",
-                                                   json_schema_extra={
-                                                       'configuration': True,
-                                                       "configuration_title": True
-                                                   })),
-            project=(str, Field(title="Project", description="ADO project", json_schema_extra={'configuration': True})),
-            repository_id=(str, Field(title="Repository ID", description="ADO repository ID",
-                                                json_schema_extra={
-                                                    'max_toolkit_length': AzureDevOpsReposToolkit.toolkit_max_length,
-                                                    'configuration': True})),
-            token=(SecretStr, Field(title="Token", description="ADO token", json_schema_extra={'secret': True, 'configuration': True})),
+            ado_repos_configuration=(AdoReposConfiguration, Field(description="Ado Repos configuration", default=None,
+                                                                       json_schema_extra={'configuration_types': ['ado_repos']})),
             base_branch=(Optional[str], Field(default="", title="Base branch", description="ADO base branch (e.g., main)")),
             active_branch=(Optional[str], Field(default="", title="Active branch", description="ADO active branch (e.g., main)")),
 
             # indexer settings
-            connection_string = (Optional[SecretStr], Field(description="Connection string for vectorstore",
-                                                            default=None,
-                                                            json_schema_extra={'secret': True})),
-            
+            pgvector_configuration=(Optional[PgVectorConfiguration], Field(default=None, description="PgVector Configuration", json_schema_extra={'configuration_types': ['pgvector']})),
+            # embedder settings
+            embedding_model=(Optional[str], Field(default=None, description="Embedding configuration.", json_schema_extra={'configuration_model': 'embedding'})),
+
             selected_tools=(List[Literal[tuple(selected_tools)]], Field(default=[], json_schema_extra={'args_schemas': selected_tools})),
             __config__={'json_schema_extra': {'metadata':
                 {
                     "label": "ADO repos",
                     "icon_url": "ado-repos-icon.svg",
-                    "sections": {
-                        "auth": {
-                            "required": True,
-                            "subsections": [
-                                {
-                                    "name": "Token",
-                                    "fields": ["token"]
-                                }
-                            ]
-                        }
-                    },
                     "categories": ["code repositories"],
                     "extra_categories": ["code", "repository", "version control"],
-                    "configuration_group": {
-                        "name": "ado_repos",
-                        "label": "Azure DevOps Repositories",
-                        "icon_url": "ado-repos-icon.svg",
-                    }
                 }}}
         )
 
@@ -112,8 +84,15 @@ class AzureDevOpsReposToolkit(BaseToolkit):
             environ["AZURE_DEVOPS_CACHE_DIR"] = "/tmp/.azure-devops"
         if selected_tools is None:
             selected_tools = []
-        
-        azure_devops_repos_wrapper = ReposApiWrapper(**kwargs)
+
+        wrapper_payload = {
+            **kwargs,
+            # TODO use ado_repos_configuration fields
+            **kwargs['ado_repos_configuration'],
+            **kwargs['ado_repos_configuration']['ado_configuration'],
+            **(kwargs.get('pgvector_configuration') or {}),
+        }
+        azure_devops_repos_wrapper = ReposApiWrapper(**wrapper_payload)
         available_tools = azure_devops_repos_wrapper.get_available_tools()
         tools = []
         prefix = clean_string(toolkit_name, cls.toolkit_max_length) + TOOLKIT_SPLITTER if toolkit_name else ''
