@@ -1,9 +1,11 @@
 from typing import List, Optional, Literal
 from .ado_wrapper import AzureDevOpsApiWrapper  # Import the API wrapper for Azure DevOps
 from langchain_core.tools import BaseTool, BaseToolkit
-from pydantic import create_model, BaseModel, Field, SecretStr
+from pydantic import create_model, BaseModel, Field
 
 import requests
+from ....configurations.ado import AdoConfiguration
+from ....configurations.pgvector import PgVectorConfiguration
 from ...base.tool import BaseAction
 from ...utils import clean_string, TOOLKIT_SPLITTER, get_max_toolkit_length, check_connection_response
 
@@ -24,28 +26,20 @@ class AzureDevOpsWorkItemsToolkit(BaseToolkit):
                                  'toolkit_name': True,
                                  'max_toolkit_length': AzureDevOpsWorkItemsToolkit.toolkit_max_length})
                   ),
-            organization_url=(str, Field(title="Organization URL",
-                                         description="ADO organization url",
-                                         json_schema_extra={
-                                             'configuration': True
-                                         })),
-            project=(str, Field(description="ADO project",
-                                json_schema_extra={
-                                    'configuration': True
-                                }
-                                )),
-            token=(SecretStr, Field(description="ADO token", json_schema_extra={'secret': True, 'configuration': True})),
+            ado_configuration=(AdoConfiguration, Field(description="Ado Work Item configuration", json_schema_extra={'configuration_types': ['ado']})),
             limit=(Optional[int], Field(description="ADO plans limit used for limitation of the list with results", default=5)),
             selected_tools=(List[Literal[tuple(selected_tools)]], Field(default=[], json_schema_extra={'args_schemas': selected_tools})),
             # indexer settings
-            connection_string = (Optional[SecretStr], Field(description="Connection string for vectorstore",
-                                                            default=None,
-                                                            json_schema_extra={'secret': True})),
+            pgvector_configuration=(Optional[PgVectorConfiguration], Field(default = None,
+                                                                           description="PgVector Configuration",
+                                                                           json_schema_extra={'configuration_types': ['pgvector']})),
+            # embedder settings
+            embedding_model=(Optional[str], Field(default=None, description="Embedding configuration.", json_schema_extra={'configuration_model': 'embedding'})),
             __config__={
                 'json_schema_extra': {
                     'metadata': {
                         "label": "ADO boards",
-                        "icon_url": None,
+                        "icon_url": "ado-boards-icon.svg",
                         "categories": ["project management"],
                         "extra_categories": ["work item management", "issue tracking", "agile boards"],
                         "sections": {
@@ -69,9 +63,12 @@ class AzureDevOpsWorkItemsToolkit(BaseToolkit):
 
         @check_connection_response
         def check_connection(self):
+            ado_config = self.ado_work_item_configuration.ado_configuration if self.ado_work_item_configuration else None
+            if not ado_config:
+                raise ValueError("ADO work item configuration is required")
             response = requests.get(
-                f'{self.organization_url}/{self.project}/_apis/wit/workitemtypes?api-version=7.0',
-                headers={'Authorization': f'Bearer {self.token}'},
+                f'{ado_config.organization_url}/{ado_config.project}/_apis/wit/workitemtypes?api-version=7.0',
+                headers={'Authorization': f'Bearer {ado_config.token}'},
                 timeout=5
             )
             return response
@@ -87,7 +84,13 @@ class AzureDevOpsWorkItemsToolkit(BaseToolkit):
         if selected_tools is None:
             selected_tools = []
 
-        azure_devops_api_wrapper = AzureDevOpsApiWrapper(**kwargs)
+        wrapper_payload = {
+            **kwargs,
+            # TODO use ado_configuration fields in AzureDevOpsApiWrapper
+            **kwargs['ado_configuration'],
+            **(kwargs.get('pgvector_configuration') or {}),
+        }
+        azure_devops_api_wrapper = AzureDevOpsApiWrapper(**wrapper_payload)
         available_tools = azure_devops_api_wrapper.get_available_tools()
         tools = []
         prefix = clean_string(toolkit_name, cls.toolkit_max_length) + TOOLKIT_SPLITTER if toolkit_name else ''
@@ -105,4 +108,3 @@ class AzureDevOpsWorkItemsToolkit(BaseToolkit):
 
     def get_tools(self):
         return self.tools
-
