@@ -214,22 +214,30 @@ class ConfluenceAPIWrapper(BaseVectorStoreToolApiWrapper):
                 "`atlassian` package not found, please run "
                 "`pip install atlassian-python-api`"
             )
-
+        if not values.get('base_url'):
+            raise ValueError("Base URL is required for Confluence API Wrapper.")
         url = values['base_url']
+        if not (values.get('token') or (values.get('api_key') and values.get('username'))):
+            raise ValueError("Either 'token' or both 'api_key' and 'username' must be provided for authentication.")
         api_key = values.get('api_key')
         username = values.get('username')
         token = values.get('token')
         cloud = values.get('cloud')
-        # if values.get('collection_name'):
-        #     values['collection_name'] = shortuuid.encode(values['collection_name'])
         if token and is_cookie_token(token):
             session = requests.Session()
             session.cookies.update(parse_cookie_string(token))
-            values['client'] = Confluence(url=url, session=session, cloud=cloud)
+            client_instance = Confluence(url=url, session=session, cloud=cloud)
         elif token:
-            values['client'] = Confluence(url=url, token=token, cloud=cloud)
+            client_instance = Confluence(url=url, token=token, cloud=cloud)
         else:
-            values['client'] = Confluence(url=url, username=username, password=api_key, cloud=cloud)
+            client_instance = Confluence(url=url, username=username, password=api_key, cloud=cloud)
+
+        custom_headers = values.get('custom_headers', {})
+        logger.info(f"Jira tool: custom headers length: {len(custom_headers)}")
+        for header, value in custom_headers.items():
+            client_instance._update_header(header, value)
+
+        values['client'] = client_instance
         return values
 
     def __unquote_confluence_space(self) -> str | None:
@@ -844,8 +852,12 @@ class ConfluenceAPIWrapper(BaseVectorStoreToolApiWrapper):
             yield document
 
     def _process_document(self, document: Document) -> Generator[Document, None, None]:
-        for attachment in self.get_page_attachments(document.metadata.get('id')):
-            yield Document(page_content=attachment.get('content', ''), metadata=attachment.get('metadata', {}))
+        attachments = self.get_page_attachments(document.metadata.get('id'))
+        if isinstance(attachments, str):
+            logger.info(f" {document.metadata.get('id')}: {attachments}")
+            return
+        for attachment in attachments:
+            yield Document(page_content=attachment.get('content', '') or attachment.get('llm_analysis', ''), metadata=attachment.get('metadata', {}))
 
     def _download_image(self, image_url):
         """
@@ -1577,7 +1589,7 @@ class ConfluenceAPIWrapper(BaseVectorStoreToolApiWrapper):
         """Return the parameters for indexing data."""
         return {
             "content_format": (Literal['view', 'storage', 'export_view', 'editor', 'anonymous'],
-                            Field(description="The format of the content to be retrieved.")),
+                            Field(description="The format of the content to be retrieved.", default='view')),
             "page_ids": (Optional[List[str]], Field(description="List of page IDs to retrieve.", default=None)),
             "label": (Optional[str], Field(description="Label to filter pages.", default=None)),
             "cql": (Optional[str], Field(description="CQL query to filter pages.", default=None)),
