@@ -2,10 +2,12 @@ from typing import List, Optional, Literal
 
 import logging
 
+from ...configurations.slack import SlackConfiguration
+
 logger = logging.getLogger(__name__)
 
 from langchain_core.tools import BaseToolkit, BaseTool
-from pydantic import create_model, BaseModel, Field, SecretStr
+from pydantic import create_model, BaseModel, Field
 from ..base.tool import BaseAction
 
 from .api_wrapper import SlackApiWrapper
@@ -18,7 +20,7 @@ name = "slack"
 def get_tools(tool):
     return SlackToolkit().get_toolkit(
         selected_tools=tool['settings'].get('selected_tools', []),
-        slack_token=tool['settings'].get('slack_token'),
+        slack_configuration=tool['settings']['slack_configuration'],
         channel_id=tool['settings'].get('channel_id'),
         toolkit_name=tool.get('toolkit_name')
     ).get_tools()
@@ -48,15 +50,18 @@ class SlackToolkit(BaseToolkit):
 
          model = create_model(
              name,
-             name=(str, Field(description="Toolkit name", json_schema_extra={'max_toolkit_length': SlackToolkit.toolkit_max_length,
-                                                                             'configuration': True,
-                                                                             'configuration_title': True})),
-             slack_token=(SecretStr, Field(description="Slack Token like XOXB-*****-*****-*****-*****",
-                                           json_schema_extra={'secret': True, 'configuration': True})),
-             channel_id=(Optional[str], Field(default=None, description="Channel ID", json_schema_extra={'configuration': True})),
+             slack_configuration=(Optional[SlackConfiguration], Field(default=None, description="Slack configuration",
+                                                             json_schema_extra={'configuration_types': ['slack']})),
              selected_tools=(List[Literal[tuple(selected_tools)]],
                              Field(default=[], json_schema_extra={'args_schemas': selected_tools})),
-             __config__={'json_schema_extra': {'metadata': {"label": "Slack", "icon_url": "slack-icon.svg"}}}
+             __config__={'json_schema_extra': {
+                'metadata': {
+                    "label": "Slack",
+                    "icon_url": "slack-icon.svg",
+                    "categories": ["communication"],
+                    "extra_categories": ["slack", "chat", "messaging", "collaboration"],
+                }
+            }}
          )
          model.check_connection = check_connection
          return model
@@ -65,7 +70,12 @@ class SlackToolkit(BaseToolkit):
     def get_toolkit(cls, selected_tools: Optional[List[str]] = None, toolkit_name: Optional[str] = None, **kwargs):
         if selected_tools is None:
             selected_tools = []
-        slack_api_wrapper = SlackApiWrapper(**kwargs)
+        wrapper_payload = {
+            **kwargs,
+            # TODO use slack_configuration fields
+            **kwargs['slack_configuration'],
+        }
+        slack_api_wrapper = SlackApiWrapper(**wrapper_payload)
         prefix = clean_string(toolkit_name, cls.toolkit_max_length) + TOOLKIT_SPLITTER if toolkit_name else ''
         available_tools = slack_api_wrapper.get_available_tools()
         tools = []
@@ -82,4 +92,3 @@ class SlackToolkit(BaseToolkit):
 
     def get_tools(self) -> List[BaseTool]:
         return self.tools
-
