@@ -1,12 +1,14 @@
 from typing import List, Literal, Optional
 
 from langchain_core.tools import BaseTool, BaseToolkit
-from pydantic import create_model, BaseModel, ConfigDict, Field, SecretStr
+from pydantic import create_model, BaseModel, ConfigDict, Field
 import requests
 
 from .api_wrapper import TestrailAPIWrapper
 from ..base.tool import BaseAction
 from ..utils import clean_string, TOOLKIT_SPLITTER, get_max_toolkit_length, check_connection_response
+from ...configurations.testrail import TestRailConfiguration
+from ...configurations.pgvector import PgVectorConfiguration
 
 name = "testrail"
 
@@ -14,16 +16,15 @@ def get_tools(tool):
     return TestrailToolkit().get_toolkit(
         selected_tools=tool['settings'].get('selected_tools', []),
         url=tool['settings']['url'],
-        password=tool['settings'].get('password', None),
-        email=tool['settings'].get('email', None),
+        testrail_configuration=tool['settings']['testrail_configuration'],
         toolkit_name=tool.get('toolkit_name'),
         llm=tool['settings'].get('llm', None),
+        alita=tool['settings'].get('alita', None),
 
         # indexer settings
-        connection_string=tool['settings'].get('connection_string', None),
-        collection_name=f"{tool.get('toolkit_name')}_{str(tool['id'])}",
-        embedding_model="HuggingFaceEmbeddings",
-        embedding_model_params={"model_name": "sentence-transformers/all-MiniLM-L6-v2"},
+        pgvector_configuration=tool['settings'].get('pgvector_configuration', {}),
+        embedding_model=tool['settings'].get('embedding_model'),
+        collection_name=f"{tool.get('toolkit_name')}",
         vectorstore_type="PGVector"
     ).get_tools()
 
@@ -38,23 +39,14 @@ class TestrailToolkit(BaseToolkit):
         TestrailToolkit.toolkit_max_length = get_max_toolkit_length(selected_tools)
         m = create_model(
             name,
-            url=(
-                str,
-                Field(
-                    description="Testrail URL",
-                    json_schema_extra={
-                        "max_length": TestrailToolkit.toolkit_max_length,
-                        "configuration": True,
-                        "configuration_title": True
-                    }
-                )
-            ),
-            email=(str, Field(description="User's email", json_schema_extra={'configuration': True})),
-            password=(SecretStr, Field(description="User's password", json_schema_extra={'secret': True, 'configuration': True})),
-            # indexer settings
-            connection_string=(Optional[SecretStr], Field(description="Connection string for vectorstore",
-                                                          default=None,
-                                                          json_schema_extra={'secret': True})),
+            name=(str, Field(description="Toolkit name", json_schema_extra={
+                'toolkit_name': True,
+                "max_length": TestrailToolkit.toolkit_max_length})),
+            testrail_configuration=(Optional[TestRailConfiguration], Field(description="TestRail Configuration", json_schema_extra={'configuration_types': ['testrail']})),
+            pgvector_configuration=(Optional[PgVectorConfiguration], Field(default = None,
+                                                                           description="PgVector Configuration", json_schema_extra={'configuration_types': ['pgvector']})),
+            # embedder settings
+            embedding_model=(Optional[str], Field(default=None, description="Embedding configuration.", json_schema_extra={'configuration_model': 'embedding'})),
             selected_tools=(List[Literal[tuple(selected_tools)]], Field(default=[], json_schema_extra={'args_schemas': selected_tools})),
             __config__=ConfigDict(json_schema_extra={'metadata':
                                                          {"label": "Testrail", "icon_url": "testrail-icon.svg",
@@ -79,7 +71,13 @@ class TestrailToolkit(BaseToolkit):
     def get_toolkit(cls, selected_tools: list[str] | None = None, toolkit_name: Optional[str] = None, **kwargs):
         if selected_tools is None:
             selected_tools = []
-        testrail_api_wrapper = TestrailAPIWrapper(**kwargs)
+        wrapper_payload = {
+            **kwargs,
+            # TODO use testrail_configuration fields
+            **kwargs['testrail_configuration'],
+            **(kwargs.get('pgvector_configuration') or {}),
+        }
+        testrail_api_wrapper = TestrailAPIWrapper(**wrapper_payload)
         prefix = clean_string(toolkit_name, cls.toolkit_max_length) + TOOLKIT_SPLITTER if toolkit_name else ''
         available_tools = testrail_api_wrapper.get_available_tools()
         tools = []
