@@ -3,11 +3,13 @@ from typing import List, Optional, Literal
 
 from langchain_community.agent_toolkits.base import BaseToolkit
 from langchain_core.tools import BaseTool
-from pydantic import create_model, BaseModel, Field, SecretStr
+from pydantic import create_model, BaseModel, Field
 
 from .api_wrapper import XrayApiWrapper
 from ..base.tool import BaseAction
 from ..utils import clean_string, get_max_toolkit_length, TOOLKIT_SPLITTER
+from ...configurations.pgvector import PgVectorConfiguration
+from ...configurations.xray import XrayConfiguration
 
 name = "xray_cloud"
 
@@ -15,19 +17,16 @@ name = "xray_cloud"
 def get_tools(tool):
     return XrayToolkit().get_toolkit(
         selected_tools=tool['settings'].get('selected_tools', []),
-        base_url=tool['settings'].get('base_url', None),
-        client_id=tool['settings'].get('client_id', None),
-        client_secret=tool['settings'].get('client_secret', None),
+        xray_configuration=tool['settings'].get('xray_configuration', {}),
         limit=tool['settings'].get('limit', 20),
         verify_ssl=tool['settings'].get('verify_ssl', True),
         toolkit_name=tool.get('toolkit_name'),
+        alita=tool['settings'].get('alita', None),
 
         # indexer settings
-        connection_string=tool['settings'].get('connection_string', None),
-        collection_name=f"{tool.get('toolkit_name')}_{str(tool['id'])}",
-        embedding_model="HuggingFaceEmbeddings",
-        embedding_model_params={"model_name": "sentence-transformers/all-MiniLM-L6-v2"},
-        vectorstore_type="PGVector"
+        pgvector_configuration=tool['settings'].get('pgvector_configuration', {}),
+        embedding_model=tool['settings'].get('embedding_model'),
+        collection_name=str(tool['toolkit_name']),
     ).get_tools()
 
 
@@ -41,10 +40,15 @@ class XrayToolkit(BaseToolkit):
         XrayToolkit.toolkit_max_length = get_max_toolkit_length(selected_tools)
         return create_model(
             name,
-            base_url=(str, Field(description="Xray URL", json_schema_extra={'toolkit_name': True, 'max_toolkit_length': XrayToolkit.toolkit_max_length})),
-            client_id=(str, Field(description="Client ID")),
-            client_secret=(SecretStr, Field(description="Client secret", json_schema_extra={'secret': True})),
             limit=(Optional[int], Field(description="Limit", default=100)),
+            xray_configuration=(XrayConfiguration, Field(description="Xray Configuration", json_schema_extra={'configuration_types': ['xray']})),
+            pgvector_configuration=(Optional[PgVectorConfiguration], Field(default=None,
+                                                                           description="PgVector Configuration",
+                                                                           json_schema_extra={
+                                                                               'configuration_types': ['pgvector']})),
+            # embedder settings
+            embedding_model=(Optional[str], Field(default=None, description="Embedding configuration.", json_schema_extra={'configuration_model': 'embedding'})),
+
             selected_tools=(List[Literal[tuple(selected_tools)]], Field(default=[], json_schema_extra={'args_schemas': selected_tools})),
             __config__={'json_schema_extra':
                             {
@@ -61,7 +65,13 @@ class XrayToolkit(BaseToolkit):
     def get_toolkit(cls, selected_tools: list[str] | None = None, toolkit_name: Optional[str] = None, **kwargs):
         if selected_tools is None:
             selected_tools = []
-        xray_api_wrapper = XrayApiWrapper(**kwargs)
+        wrapper_payload = {
+            **kwargs,
+            # Use xray_configuration fields
+            **(kwargs.get('xray_configuration') or {}),
+            **(kwargs.get('pgvector_configuration') or {}),
+        }
+        xray_api_wrapper = XrayApiWrapper(**wrapper_payload)
         prefix = clean_string(toolkit_name, cls.toolkit_max_length) + TOOLKIT_SPLITTER if toolkit_name else ''
         available_tools = xray_api_wrapper.get_available_tools()
         tools = []
